Page 51 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 51

Home

    in one's opinion he flew into a rage and foamed at the
    mouth."”

    Following the 10th of August, Marat began to incite
    the population to massacre the Royalists and Swiss who
    had been imprisoned. Meeting in secret, Marat and his
    supporters plotted the details of the massacres of
    September. For the purpose of robbery, a number of
    wealthy people were to also be incarcerated. Many of
    their rivals were added to the list. All of these

    unfortunate victims were to be imprisoned and put to
    death without a trial of any kind.

    The difficulty in finding enough hands to murder
    hundreds of prisoners necessitated liberating a number of
    thieves and murderers from prison. Female malefactors

    were sometimes released to make up an audience to
    applaud and incite the murderers to further acts of
    violence.

    prisons, the vast majority were from the common people.
    This list included many young boys, twelve years old and
    up, who were street urchins detained for minor offenses.
    At a house of corrections for women, thirty-five victims
    perished, some being girls ten to fifteen years of age.
    Among the victims there were also more than two-
    hundred priests. These were humble, saintly men, many
    white haired with age, who had spent their lives in doing
    good. They met their death with a heroic resignation
    unsurpassed even by the martyrs of the early church.

    46

    The Secret Side of History

    Out of well over a thousand victims from nine